@@ -477,7 +477,7 @@ static void gdl_dock_bar_size_vrequest (GtkWidget *widget,
       child = children->data;
       children = children->next;
 
-      if (GTK_WIDGET_VISIBLE (child->widget))
+      if (gtk_widget_get_visible (child->widget))
 	{
 	  gtk_widget_size_request (child->widget, &child_requisition);
 
@@ -535,7 +535,7 @@ static void gdl_dock_bar_size_vallocate (GtkWidget     *widget,
       child = children->data;
       children = children->next;
 
-      if (GTK_WIDGET_VISIBLE (child->widget))
+      if (gtk_widget_get_visible (child->widget))
 	{
 	  nvis_children += 1;
 	  if (child->expand)
@@ -573,7 +573,7 @@ static void gdl_dock_bar_size_vallocate (GtkWidget     *widget,
 	  child = children->data;
 	  children = children->next;
 
-	  if ((child->pack == GTK_PACK_START) && GTK_WIDGET_VISIBLE (child->widget))
+	  if ((child->pack == GTK_PACK_START) && gtk_widget_get_visible (child->widget))
 	    {
 	      if (box->homogeneous)
 		{
@@ -632,7 +632,7 @@ static void gdl_dock_bar_size_vallocate (GtkWidget     *widget,
 	  child = children->data;
 	  children = children->next;
 
-	  if ((child->pack == GTK_PACK_END) && GTK_WIDGET_VISIBLE (child->widget))
+	  if ((child->pack == GTK_PACK_END) && gtk_widget_get_visible (child->widget))
 	    {
 	      GtkRequisition child_requisition;
 	      gtk_widget_get_child_requisition (child->widget, &child_requisition);
@@ -702,7 +702,7 @@ static void gdl_dock_bar_size_hrequest (GtkWidget *widget,
       child = children->data;
       children = children->next;
 
-      if (GTK_WIDGET_VISIBLE (child->widget))
+      if (gtk_widget_get_visible (child->widget))
 	{
 	  GtkRequisition child_requisition;
 
@@ -764,7 +764,7 @@ static void gdl_dock_bar_size_hallocate (GtkWidget     *widget,
       child = children->data;
       children = children->next;
 
-      if (GTK_WIDGET_VISIBLE (child->widget))
+      if (gtk_widget_get_visible (child->widget))
 	{
 	  nvis_children += 1;
 	  if (child->expand)
@@ -802,7 +802,7 @@ static void gdl_dock_bar_size_hallocate (GtkWidget     *widget,
 	  child = children->data;
 	  children = children->next;
 
-	  if ((child->pack == GTK_PACK_START) && GTK_WIDGET_VISIBLE (child->widget))
+	  if ((child->pack == GTK_PACK_START) && gtk_widget_get_visible (child->widget))
 	    {
 	      if (box->homogeneous)
 		{
@@ -865,7 +865,7 @@ static void gdl_dock_bar_size_hallocate (GtkWidget     *widget,
 	  child = children->data;
 	  children = children->next;
 
-	  if ((child->pack == GTK_PACK_END) && GTK_WIDGET_VISIBLE (child->widget))
+	  if ((child->pack == GTK_PACK_END) && gtk_widget_get_visible (child->widget))
 	    {
 	      GtkRequisition child_requisition;
 	      gtk_widget_get_child_requisition (child->widget, &child_requisition);
