@@ -174,12 +174,15 @@ struct _GdlDockItemPrivate {
     guint      grip_size;
     
     GtkWidget *tab_label;
+    gboolean  intern_tab_label;
+    guint     notify_label;
+    guint     notify_stock_id;
 
     gint       preferred_width;
     gint       preferred_height;
 
     GdlDockPlaceholder *ph;
-
+    
     gint       start_x, start_y;
 };
 
@@ -419,10 +422,33 @@ gdl_dock_item_instance_init (GdlDockItem *item)
 
     item->_priv->preferred_width = item->_priv->preferred_height = -1;
     item->_priv->tab_label = NULL;
+    item->_priv->intern_tab_label = FALSE;
 
     item->_priv->ph = NULL;
 }
 
+static void
+on_long_name_changed (GObject* item,
+                      GParamSpec* spec,
+                      gpointer user_data)
+{
+    gchar* long_name;
+    g_object_get (item, "long-name", &long_name, NULL);
+    gtk_label_set_label (GTK_LABEL (user_data), long_name);
+    g_free(long_name);
+}
+
+static void
+on_stock_id_changed (GObject* item,
+                      GParamSpec* spec,
+                      gpointer user_data)
+{
+    gchar* stock_id;
+    g_object_get (item, "stock_id", &stock_id, NULL);
+    gtk_image_set_from_stock (GTK_IMAGE (user_data), stock_id, GTK_ICON_SIZE_MENU);
+    g_free(stock_id);
+}
+
 static GObject *
 gdl_dock_item_constructor (GType                  type,
                            guint                  n_construct_properties,
@@ -438,6 +464,11 @@ gdl_dock_item_constructor (GType                  type,
                                                NULL);
     if (g_object) {
         GdlDockItem *item = GDL_DOCK_ITEM (g_object);
+        GtkWidget *hbox;
+        GtkWidget *label;
+        GtkWidget *icon;
+        gchar* long_name;
+        gchar* stock_id;
 
         if (GDL_DOCK_ITEM_HAS_GRIP (item)) {
             item->_priv->grip_shown = TRUE;
@@ -448,6 +479,32 @@ gdl_dock_item_constructor (GType                  type,
         else {
             item->_priv->grip_shown = FALSE;
         }
+
+        g_object_get (g_object, "long-name", &long_name, "stock-id", &stock_id, NULL);
+
+        hbox = gtk_hbox_new (FALSE, 5);    
+        label = gtk_label_new (long_name);
+        icon = gtk_image_new ();
+        if (stock_id)
+            gtk_image_set_from_stock (GTK_IMAGE (icon), stock_id, 
+                                      GTK_ICON_SIZE_MENU);
+        gtk_box_pack_start (GTK_BOX (hbox), icon, FALSE, FALSE, 0);
+        gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 0);
+
+        item->_priv->notify_label = 
+            g_signal_connect (item, "notify::long-name", G_CALLBACK (on_long_name_changed),
+                              label);
+        item->_priv->notify_stock_id = 
+            g_signal_connect (item, "notify::stock-id", G_CALLBACK (on_stock_id_changed),
+                              icon);
+        
+        gtk_widget_show_all (hbox);
+        
+        gdl_dock_item_set_tablabel (item, hbox);
+        item->_priv->intern_tab_label = TRUE;
+
+        g_free (long_name);
+        g_free (stock_id);
     }
 
     return g_object;
@@ -620,7 +677,7 @@ gdl_dock_item_remove (GtkContainer *container,
     
     item = GDL_DOCK_ITEM (container);
     if (item->_priv && widget == item->_priv->grip) {
-        gboolean grip_was_visible = GTK_WIDGET_VISIBLE (widget);
+        gboolean grip_was_visible = gtk_widget_get_visible (widget);
         gtk_widget_unparent (widget);
         item->_priv->grip = NULL;
         if (grip_was_visible)
@@ -634,7 +691,7 @@ gdl_dock_item_remove (GtkContainer *container,
     
     g_return_if_fail (item->child == widget);
     
-    was_visible = GTK_WIDGET_VISIBLE (widget);
+    was_visible = gtk_widget_get_visible (widget);
 
     gtk_widget_unparent (widget);
     item->child = NULL;
@@ -744,14 +801,14 @@ gdl_dock_item_size_allocate (GtkWidget     *widget,
     item->_priv->preferred_height = -1;
     item->_priv->preferred_width = -1;
     
-    if (GTK_WIDGET_REALIZED (widget))
+    if (gtk_widget_get_realized (widget))
         gdk_window_move_resize (widget->window,
                                 widget->allocation.x,
                                 widget->allocation.y,
                                 widget->allocation.width,
                                 widget->allocation.height);
 
-    if (item->child && GTK_WIDGET_VISIBLE (item->child)) {
+    if (item->child && gtk_widget_get_visible (item->child)) {
         GtkAllocation  child_allocation;
         int            border_width;
 
@@ -806,13 +863,13 @@ gdl_dock_item_map (GtkWidget *widget)
     gdk_window_show (widget->window);
 
     if (item->child
-        && GTK_WIDGET_VISIBLE (item->child)
-        && !GTK_WIDGET_MAPPED (item->child))
+        && gtk_widget_get_visible (item->child)
+        && !gtk_widget_get_mapped (item->child))
         gtk_widget_map (item->child);
 
     if (item->_priv->grip
-        && GTK_WIDGET_VISIBLE (item->_priv->grip)
-        && !GTK_WIDGET_MAPPED (item->_priv->grip))
+        && gtk_widget_get_visible (GTK_WIDGET (item->_priv->grip))
+        && !gtk_widget_get_mapped (GTK_WIDGET (item->_priv->grip)))
         gtk_widget_map (item->_priv->grip);
 }
 
@@ -869,7 +926,7 @@ gdl_dock_item_realize (GtkWidget *widget)
   
     widget->style = gtk_style_attach (widget->style, widget->window);
     gtk_style_set_background (widget->style, widget->window, 
-                              GTK_WIDGET_STATE (item));
+                              gtk_widget_get_state (GTK_WIDGET (item)));
     gdk_window_set_back_pixmap (widget->window, NULL, TRUE);
 
     if (item->child)
@@ -886,10 +943,12 @@ gdl_dock_item_style_set (GtkWidget *widget,
     g_return_if_fail (widget != NULL);
     g_return_if_fail (GDL_IS_DOCK_ITEM (widget));
 
-    if (GTK_WIDGET_REALIZED (widget) && !GTK_WIDGET_NO_WINDOW (widget)) {
+    if (gtk_widget_get_realized (widget) &&
+            gtk_widget_get_has_window (widget))
+    {
         gtk_style_set_background (widget->style, widget->window,
                                   widget->state);
-        if (GTK_WIDGET_DRAWABLE (widget))
+        if (gtk_widget_is_drawable (widget))
             gdk_window_clear (widget->window);
     }
 }
@@ -904,7 +963,7 @@ gdl_dock_item_paint (GtkWidget      *widget,
 
     gtk_paint_box (widget->style,
                    widget->window,
-                   GTK_WIDGET_STATE (widget),
+                   gtk_widget_get_state (widget),
                    GTK_SHADOW_NONE,
                    &event->area, widget,
                    "dockitem",
@@ -919,7 +978,7 @@ gdl_dock_item_expose (GtkWidget      *widget,
     g_return_val_if_fail (GDL_IS_DOCK_ITEM (widget), FALSE);
     g_return_val_if_fail (event != NULL, FALSE);
 
-    if (GTK_WIDGET_DRAWABLE (widget) && event->window == widget->window) {
+    if (gtk_widget_is_drawable (widget) && event->window == widget->window) {
         gdl_dock_item_paint (widget, event);
         GDL_CALL_PARENT_GBOOLEAN(GTK_WIDGET_CLASS, expose_event, (widget,event));
     }
@@ -1374,7 +1433,7 @@ gdl_dock_item_dock (GdlDockObject    *object,
             gtk_container_add (GTK_CONTAINER (parent), GTK_WIDGET (new_parent));
 
         /* show automatic object */
-        if (GTK_WIDGET_VISIBLE (object))
+        if (gtk_widget_get_visible (GTK_WIDGET (object)))
         {
             gtk_widget_show (GTK_WIDGET (new_parent));
             GDL_DOCK_OBJECT_UNSET_FLAGS (object, GDL_DOCK_IN_REFLOW);
@@ -1470,7 +1529,7 @@ gdl_dock_item_drag_start (GdlDockItem *item)
 {
     GdkCursor *fleur;
 
-    if (!GTK_WIDGET_REALIZED (item))
+    if (!gtk_widget_get_realized (GTK_WIDGET (item)))
         gtk_widget_realize (GTK_WIDGET (item));
     
     GDL_DOCK_ITEM_SET_FLAGS (item, GDL_DOCK_IN_DRAG);
@@ -1596,7 +1655,7 @@ gdl_dock_item_real_set_orientation (GdlDockItem    *item,
 {
     item->orientation = orientation;
     
-    if (GTK_WIDGET_DRAWABLE (item))
+    if (gtk_widget_is_drawable (GTK_WIDGET (item)))
         gtk_widget_queue_draw (GTK_WIDGET (item));
     gtk_widget_queue_resize (GTK_WIDGET (item));
 }
@@ -1628,7 +1687,6 @@ gdl_dock_item_new (const gchar         *name,
                                         "behavior", behavior,
                                         NULL));
     GDL_DOCK_OBJECT_UNSET_FLAGS (item, GDL_DOCK_AUTOMATIC);
-    gdl_dock_item_set_tablabel (item, gtk_label_new (long_name));
 
     return GTK_WIDGET (item);
 }
@@ -1660,8 +1718,7 @@ gdl_dock_item_new_with_stock (const gchar         *name,
                                         "behavior", behavior,
                                         NULL));
     GDL_DOCK_OBJECT_UNSET_FLAGS (item, GDL_DOCK_AUTOMATIC);
-    gdl_dock_item_set_tablabel (item, gtk_label_new (long_name));
-
+    
     return GTK_WIDGET (item);
 }
 
@@ -1669,7 +1726,7 @@ gdl_dock_item_new_with_stock (const gchar         *name,
 /**
  * gdl_dock_item_dock_to:
  * @item: The dock item that will be relocated to the dock position.
- * @target: The dock item that will be used as the point of reference.
+ * @target: (allow-none): The dock item that will be used as the point of reference.
  * @position: The position to dock #item, relative to #target.
  * @docking_param: This value is unused, and will be ignored.
  * 
@@ -1780,6 +1837,13 @@ gdl_dock_item_set_tablabel (GdlDockItem *item,
 {
     g_return_if_fail (item != NULL);
 
+    if (item->_priv->intern_tab_label)
+    {
+        item->_priv->intern_tab_label = FALSE;
+        g_signal_handler_disconnect (item, item->_priv->notify_label);        
+        g_signal_handler_disconnect (item, item->_priv->notify_stock_id);
+    }
+    
     if (item->_priv->tab_label) {
         /* disconnect and unref the previous tablabel */
         if (GDL_IS_DOCK_TABLABEL (item->_priv->tab_label)) {
@@ -1816,7 +1880,7 @@ gdl_dock_item_set_tablabel (GdlDockItem *item,
 GtkWidget *
 gdl_dock_item_get_grip(GdlDockItem *item)
 {
-    g_return_if_fail (item != NULL);
+    g_return_val_if_fail (item != NULL, NULL);
     g_return_val_if_fail (GDL_IS_DOCK_ITEM (item), NULL);
 
     return item->_priv->grip;
