@@ -458,7 +458,6 @@ gdl_dock_set_title (GdlDock *dock)
 {
     GdlDockObject *object = GDL_DOCK_OBJECT (dock);
     gchar         *title = NULL;
-    gboolean       free_title = FALSE;
     
     if (!dock->_priv->window)
         return;
@@ -468,25 +467,22 @@ gdl_dock_set_title (GdlDock *dock)
     }
     else if (object->master) {
         g_object_get (object->master, "default-title", &title, NULL);
-        free_title = TRUE;
     }
 
     if (!title && dock->root) {
         g_object_get (dock->root, "long-name", &title, NULL);
-        free_title = TRUE;
     }
     
     if (!title) {
         /* set a default title in the long_name */
         dock->_priv->auto_title = TRUE;
-        free_title = FALSE;
-        title = object->long_name = g_strdup_printf (
+        title = g_strdup_printf (
             _("Dock #%d"), GDL_DOCK_MASTER (object->master)->dock_number++);
     }
 
     gtk_window_set_title (GTK_WINDOW (dock->_priv->window), title);
-    if (free_title)
-        g_free (title);
+
+    g_free (title);
 }
 
 static void
@@ -495,12 +491,21 @@ gdl_dock_notify_cb (GObject    *object,
                     gpointer    user_data)
 {
     GdlDock *dock;
+    gchar* long_name;
     
     g_return_if_fail (object != NULL || GDL_IS_DOCK (object));
-    
-    dock = GDL_DOCK (object);
-    dock->_priv->auto_title = FALSE;
-    gdl_dock_set_title (dock);
+
+    g_object_get (object, "long-name", &long_name, NULL);
+
+    g_message ("Notify long_name: %s", long_name);
+
+    if (long_name)
+    {
+        dock = GDL_DOCK (object);
+        dock->_priv->auto_title = FALSE;
+        gdl_dock_set_title (dock);
+    }
+    g_free (long_name);
 }
 
 static void
@@ -546,7 +551,7 @@ gdl_dock_size_request (GtkWidget      *widget,
     border_width = container->border_width;
 
     /* make request to root */
-    if (dock->root && GTK_WIDGET_VISIBLE (dock->root))
+    if (dock->root && gtk_widget_get_visible (GTK_WIDGET (dock->root)))
         gtk_widget_size_request (GTK_WIDGET (dock->root), requisition);
     else {
         requisition->width = 0;
@@ -582,7 +587,7 @@ gdl_dock_size_allocate (GtkWidget     *widget,
     allocation->width = MAX (1, allocation->width - 2 * border_width);
     allocation->height = MAX (1, allocation->height - 2 * border_width);
 
-    if (dock->root && GTK_WIDGET_VISIBLE (dock->root))
+    if (dock->root && gtk_widget_get_visible (GTK_WIDGET (dock->root)))
         gtk_widget_size_allocate (GTK_WIDGET (dock->root), allocation);
 }
 
@@ -601,7 +606,7 @@ gdl_dock_map (GtkWidget *widget)
 
     if (dock->root) {
         child = GTK_WIDGET (dock->root);
-        if (GTK_WIDGET_VISIBLE (child) && !GTK_WIDGET_MAPPED (child))
+        if (gtk_widget_get_visible (child) && !gtk_widget_get_mapped (child))
             gtk_widget_map (child);
     }
 }
@@ -621,7 +626,7 @@ gdl_dock_unmap (GtkWidget *widget)
 
     if (dock->root) {
         child = GTK_WIDGET (dock->root);
-        if (GTK_WIDGET_VISIBLE (child) && GTK_WIDGET_MAPPED (child))
+        if (gtk_widget_get_visible (child) && gtk_widget_get_mapped (child))
             gtk_widget_unmap (child);
     }
     
@@ -705,14 +710,14 @@ gdl_dock_remove (GtkContainer *container,
     g_return_if_fail (widget != NULL);
 
     dock = GDL_DOCK (container);
-    was_visible = GTK_WIDGET_VISIBLE (widget);
+    was_visible = gtk_widget_get_visible (widget);
 
     if (GTK_WIDGET (dock->root) == widget) {
         dock->root = NULL;
         GDL_DOCK_OBJECT_UNSET_FLAGS (widget, GDL_DOCK_ATTACHED);
         gtk_widget_unparent (widget);
 
-        if (was_visible && GTK_WIDGET_VISIBLE (GTK_WIDGET (container)))
+        if (was_visible && gtk_widget_get_visible (GTK_WIDGET (container)))
             gtk_widget_queue_resize (GTK_WIDGET (dock));
     }
 }
@@ -912,15 +917,15 @@ gdl_dock_dock (GdlDockObject    *object,
 
         /* Realize the item (create its corresponding GdkWindow) when 
            GdlDock has been realized. */
-        if (GTK_WIDGET_REALIZED (dock))
+        if (gtk_widget_get_realized (GTK_WIDGET (dock)))
             gtk_widget_realize (widget);
         
         /* Map the widget if it's visible and the parent is visible and has 
            been mapped. This is done to make sure that the GdkWindow is 
            visible. */
-        if (GTK_WIDGET_VISIBLE (dock) && 
-            GTK_WIDGET_VISIBLE (widget)) {
-            if (GTK_WIDGET_MAPPED (dock))
+        if (gtk_widget_get_visible (GTK_WIDGET (dock)) && 
+            gtk_widget_get_visible (widget)) {
+            if (gtk_widget_get_mapped (GTK_WIDGET (dock)))
                 gtk_widget_map (widget);
             
             /* Make the widget resize. */
@@ -1249,9 +1254,9 @@ gdl_dock_add_floating_item (GdlDock        *dock,
                                        "floaty", y,
                                        NULL));
     
-    if (GTK_WIDGET_VISIBLE (dock)) {
+    if (gtk_widget_get_visible (GTK_WIDGET (dock))) {
         gtk_widget_show (GTK_WIDGET (new_dock));
-        if (GTK_WIDGET_MAPPED (dock))
+        if (gtk_widget_get_mapped (GTK_WIDGET (dock)))
             gtk_widget_map (GTK_WIDGET (new_dock));
         
         /* Make the widget resize. */
@@ -1326,7 +1331,7 @@ gdl_dock_xor_rect (GdlDock      *dock,
     widget = GTK_WIDGET (dock);
 
     if (!dock->_priv->xor_gc) {
-        if (GTK_WIDGET_REALIZED (widget)) {
+        if (gtk_widget_get_realized (widget)) {
             GdkGCValues values;
 
             values.function = GDK_INVERT;
